Changelog
=========


(unreleased)
------------
- Updates. [jkobject]


1.3.1 (2025-12-01)
------------------
- Release: version 1.3.1 🚀 [jkobject]
- Much better plots. [jkobject]
- Better plots. [jkobject]
- Debugs for uv install. [jkobject]
- Nothing really. [jkobject-tower]
- Debug. [jkobject]
- Merge branch 'main' of https://github.com/cantinilab/GRnnData.
  [jkobject]
- Update LICENSE. [Jérémie Kalfon]
- Small improvements. [jkobject]
- Adding versions. [jkobject]
- Update README.md. [Jérémie Kalfon]
- Cleanups. [maestro-jk]
- Debug in some cases. [maestro-jk]
- Merge pull request #6 from
  cantinilab/dependabot/github_actions/astral-sh/setup-uv-4. [Jérémie
  Kalfon]

  Bump astral-sh/setup-uv from 3 to 4
- Bump astral-sh/setup-uv from 3 to 4. [dependabot[bot]]

  Bumps [astral-sh/setup-uv](https://github.com/astral-sh/setup-uv) from 3 to 4.
  - [Release notes](https://github.com/astral-sh/setup-uv/releases)
  - [Commits](https://github.com/astral-sh/setup-uv/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: astral-sh/setup-uv
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Adding version. [maestro-jk]


1.1.5 (2024-11-27)
------------------
- Release: version 1.1.5 🚀 [maestro-jk]
- Merge pull request #5 from
  cantinilab/dependabot/github_actions/codecov/codecov-action-5.
  [Jérémie Kalfon]

  Bump codecov/codecov-action from 4 to 5
- Bump codecov/codecov-action from 4 to 5. [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 4 to 5.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge branch 'main' of https://github.com/cantinilab/GRnnData into
  main. [jkobject]
- Update README.md. [Jérémie Kalfon]
- Add files via upload. [Jérémie Kalfon]
- Nothing. [jkobject]
- Merge branch 'main' of https://github.com/cantinilab/GRnnData.
  [maestro-jk]
- Making it fail  and few debugs. [jkobject]
- Update README.md. [Jérémie Kalfon]
- Merge pull request #4 from
  cantinilab/dependabot/github_actions/softprops/action-gh-release-2.
  [Jérémie Kalfon]

  Bump softprops/action-gh-release from 1 to 2
- Bump softprops/action-gh-release from 1 to 2. [dependabot[bot]]

  Bumps [softprops/action-gh-release](https://github.com/softprops/action-gh-release) from 1 to 2.
  - [Release notes](https://github.com/softprops/action-gh-release/releases)
  - [Changelog](https://github.com/softprops/action-gh-release/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/softprops/action-gh-release/compare/v1...v2)

  ---
  updated-dependencies:
  - dependency-name: softprops/action-gh-release
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Adding setuptools. [jkobject]
- Added coverage and better install. [jkobject]
- New grnndata. [maestro-jk]


1.1.4 (2024-10-08)
------------------
- Release: version 1.1.4 🚀 [jkobject]
- Update. [jkobject]


1.1.3 (2024-10-08)
------------------
- Release: version 1.1.3 🚀 [jkobject]
- Added ruff and uv. [jkobject]
- Better tests. [jkobject]


1.1.2 (2024-09-04)
------------------
- Release: version 1.1.2 🚀 [jkobject]
- More tests. [jkobject]


1.1.1 (2024-09-04)
------------------
- Release: version 1.1.1 🚀 [jkobject]
- Makefile update. [jkobject]


1.1.0 (2024-09-04)
------------------
- Release: version 1.1.0 🚀 [jkobject]
- Better release process. [jkobject]
- Format and clean. [jkobject]
- Wip. [jkobject]
- Pushing the tests. [jkobject]
- Adding codecov. [jkobject]
- Updating the makefile. [jkobject]
- Update package version. [jkobject]


1.0.2 (2024-08-11)
------------------
- Release: version 1.0.2 🚀 [jkobject]
- Release: version 1.0.1 🚀 [jkobject]
- Debug. [jkobject]
- Adding tests. [jkobject]
- Adding documentation. [jkobject]


1.0.0 (2024-08-06)
------------------
- Release: version 1.0.0 🚀 [jkobject]
- Merge branch 'dev' into main. [jkobject]
- Debug enrichment and centrality. [jkobject]
- Adding new plotting. [jkobject]
- Merge branch 'dev' of https://github.com/cantinilab/GRnnData into dev.
  [jkobject]
- Adding background. [maestro-jk]
- Better background. [jkobject]
- Some more debugs. [jkobject]
- Solve issues. [jkobject]
- Wip on plotting gene networks. [jkobject]
- Making it work on new hardware. [maestro-jk]
- Tiny side case. [jkobject]
- Better utils. [jkobject]
- Working with mouse. [jkobject]
- Some new methods. [jkobject]
- Some more install requirements and new functions. [jkobject]
- Some more docs and better deps. [jkobject]
- Adding some more features. [jkobject]
- Update README.md. [Jérémie Kalfon]


1.0.1 (2024-01-11)
------------------
- Making the release. [jkobject]
- Working on improving grnndata. [jkobject]
- Testing and creating a first version of GRnnData. [jkobject]
- Finish switch to peotry. [jkobject]
- Update LICENSE. [Jérémie Kalfon]
- Improving and making it ready for first release. [jkobject]
- Update. [jkobject]
- Update extract_links to return output sorted by scores. [Rémi
  Trimbour]
- Add mu file. [jkobject]
- Merge pull request #1 from
  cantinilab/dependabot/github_actions/stefanzweifel/git-auto-commit-
  action-5. [Jérémie Kalfon]

  Bump stefanzweifel/git-auto-commit-action from 4 to 5
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]

  Bumps [stefanzweifel/git-auto-commit-action](https://github.com/stefanzweifel/git-auto-commit-action) from 4 to 5.
  - [Release notes](https://github.com/stefanzweifel/git-auto-commit-action/releases)
  - [Changelog](https://github.com/stefanzweifel/git-auto-commit-action/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/stefanzweifel/git-auto-commit-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: stefanzweifel/git-auto-commit-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #3 from
  cantinilab/dependabot/github_actions/actions/setup-python-5. [Jérémie
  Kalfon]

  Bump actions/setup-python from 4 to 5
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- ✅ Ready to clone and code. [jkobject]
- Initial commit. [Jérémie Kalfon]


